@@ -5,6 +5,7 @@
 
     var HELPER = "/usr/sbin/edubuntu-menu-admin-helper";
     var QUERY  = "/usr/share/cockpit/edubuntu-menu-admin/query.py";
+    var TERMINAL_SENTINEL = "__disable_terminal_shortcut__";
 
     var state = null;   // loaded from query.py
     var activeTab = "tab-global";
@@ -89,9 +90,17 @@
             }
             cb.addEventListener("change", checkChanges);
             lbl.appendChild(cb);
-            var nameText = " " + (app.name || app.id);
-            if (isDisabled) {
-                nameText += "  (" + _("hidden globally") + ")";
+            var nameText;
+            if (app.id === TERMINAL_SENTINEL) {
+                nameText = " " + _("Disable terminal keyboard shortcut") + " (Ctrl+Alt+T)";
+                if (isDisabled) {
+                    nameText += "  (" + _("disabled globally") + ")";
+                }
+            } else {
+                nameText = " " + (app.name || app.id);
+                if (isDisabled) {
+                    nameText += "  (" + _("hidden globally") + ")";
+                }
             }
             lbl.appendChild(document.createTextNode(nameText));
             container.appendChild(lbl);
