@@ -13,6 +13,9 @@ SNAP_APPS_DIR = Path("/var/lib/snapd/desktop/applications")
 OVERRIDE_DIR = Path("/usr/share/edubuntu/applications")
 SKIP_FILES = frozenset({"defaults.list", "mimeinfo.cache", "kde-mimeapps.list"})
 
+TERMINAL_SENTINEL = "__disable_terminal_shortcut__"
+DCONF_TERMINAL_FILE = Path("/etc/dconf/db/site.d/02_edubuntu_terminal")
+
 
 def has_no_display(filepath):
     try:
@@ -115,12 +118,31 @@ def user_hidden_set(username, app_ids):
 def main():
     apps = build_app_table()
     app_ids = [a["id"] for a in apps]
+
+    # Add terminal shortcut toggle as a virtual entry at the top
+    terminal_disabled_global = DCONF_TERMINAL_FILE.exists()
+    apps.insert(0, {
+        "id": TERMINAL_SENTINEL,
+        "name": "Disable terminal keyboard shortcut (Ctrl+Alt+T)",
+        "hidden_global": terminal_disabled_global,
+    })
+
     users = list_non_admin_users()
     user_data = []
     for u in users:
+        hidden = user_hidden_set(u, app_ids)
+        # Check terminal shortcut marker for this user
+        try:
+            homedir = pwd.getpwnam(u).pw_dir
+            if os.path.isfile(
+                os.path.join(homedir, ".config", "edubuntu", "terminal-disabled")
+            ):
+                hidden.append(TERMINAL_SENTINEL)
+        except KeyError:
+            pass
         user_data.append({
             "username": u,
-            "hidden": user_hidden_set(u, app_ids),
+            "hidden": hidden,
         })
 
     json.dump({"apps": apps, "users": user_data}, sys.stdout)
