@@ -17,11 +17,15 @@ ICON_PATH = "/usr/share/icons/hicolor/scalable/apps/edubuntu-menu-admin.svg"
 
 HELPER = "/usr/sbin/edubuntu-menu-admin-helper"
 
+TERMINAL_TOGGLE_KEY = "__disable_terminal_shortcut__"
+
 _SYSTEM_APPS_DIR = Path("/usr/share/applications")
 _SNAP_APPS_DIR = Path("/var/lib/snapd/desktop/applications")
 _OVERRIDE_DIR = Path("/usr/share/edubuntu/applications")
 _SKIP_FILES = frozenset({"defaults.list", "mimeinfo.cache", "kde-mimeapps.list"})
 
+_DCONF_TERMINAL_FILE = Path("/etc/dconf/db/site.d/02_edubuntu_terminal")
+
 
 @dataclass
 class DesktopEntry:
@@ -199,6 +203,11 @@ def apply_user_hidden(username: str, filenames: list[str]) -> bool:
         return False
 
 
+def query_terminal_global() -> bool:
+    """Return True if the terminal keyboard shortcut is globally disabled."""
+    return _DCONF_TERMINAL_FILE.exists()
+
+
 def is_gnome_session() -> bool:
     desktop = os.environ.get("XDG_CURRENT_DESKTOP", "").lower()
     session = os.environ.get("DESKTOP_SESSION", "").lower()
