@@ -13,12 +13,14 @@ if str(_pkg_dir) not in sys.path:
 
 from backend import (  # noqa: E402
     APP_TITLE,
+    TERMINAL_TOGGLE_KEY,
     apply_global_hidden,
     apply_user_hidden,
     build_desktop_table,
     build_user_desktop_table,
     is_gnome_session,
     list_non_admin_users,
+    query_terminal_global,
     query_user_hidden,
     reset_gnome_apps,
 )
@@ -109,10 +111,12 @@ def _main_loop(ui: MenuAdminUI) -> None:
     while True:
         table = [None]
         users = [[]]
+        terminal_global = [False]
 
         def _build():
             table[0] = build_desktop_table()
             users[0] = list_non_admin_users()
+            terminal_global[0] = query_terminal_global()
 
         ui.show_progress(APP_TITLE, _("Scanning applications…"), _build)
 
@@ -128,6 +132,13 @@ def _main_loop(ui: MenuAdminUI) -> None:
         user_hidden = query_user_hidden(usernames) if usernames else {}
 
         global_items = [
+            ChecklistItem(
+                key=TERMINAL_TOGGLE_KEY,
+                label=_("Disable terminal keyboard shortcut"),
+                description="Ctrl+Alt+T",
+                checked=terminal_global[0],
+            ),
+        ] + [
             ChecklistItem(
                 key=entry.filename,
                 label=entry.filename,
@@ -144,7 +155,26 @@ def _main_loop(ui: MenuAdminUI) -> None:
             user_table = build_user_desktop_table(
                 username, hidden_files=user_hidden.get(username),
             )
-            return [
+
+            # Terminal toggle for this user
+            user_hidden_set = user_hidden.get(username, set())
+            terminal_globally = TERMINAL_TOGGLE_KEY in globally_hidden
+            terminal_user = TERMINAL_TOGGLE_KEY in user_hidden_set
+            items = [
+                ChecklistItem(
+                    key=TERMINAL_TOGGLE_KEY,
+                    label=_("Disable terminal keyboard shortcut"),
+                    description=(
+                        "Ctrl+Alt+T  (" + _("disabled globally") + ")"
+                        if terminal_globally
+                        else "Ctrl+Alt+T"
+                    ),
+                    checked=terminal_user or terminal_globally,
+                    disabled=terminal_globally,
+                ),
+            ]
+
+            items.extend([
                 ChecklistItem(
                     key=e.filename,
                     label=e.filename,
@@ -157,7 +187,8 @@ def _main_loop(ui: MenuAdminUI) -> None:
                     disabled=e.filename in globally_hidden,
                 )
                 for e in user_table
-            ]
+            ])
+            return items
 
         result = ui.show_tabbed_checklist(
             APP_TITLE,
